@@ -68,7 +68,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 19 "../../drawtiming/src/parser.yy"
+#line 19 "parser.yy"
 
 #include "globals.h"
 void yyerror (const char *s);
@@ -978,53 +978,53 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 35 "../../drawtiming/src/parser.yy"
+#line 35 "parser.yy"
     { ++ n; }
     break;
 
   case 5:
-#line 36 "../../drawtiming/src/parser.yy"
+#line 36 "parser.yy"
     { deps.clear (); ++ n; }
     break;
 
   case 6:
-#line 39 "../../drawtiming/src/parser.yy"
+#line 39 "parser.yy"
     { yyval = yyvsp[0]; deps.push_back (yyvsp[0]); }
     break;
 
   case 7:
-#line 40 "../../drawtiming/src/parser.yy"
+#line 40 "parser.yy"
     { yyval = yyvsp[0]; deps.push_back (yyvsp[0]); }
     break;
 
   case 8:
-#line 41 "../../drawtiming/src/parser.yy"
+#line 41 "parser.yy"
     { yyval = yyvsp[0]; deps.clear (); deps.push_back (yyvsp[0]); }
     break;
 
   case 9:
-#line 42 "../../drawtiming/src/parser.yy"
+#line 42 "parser.yy"
     { yyval = yyvsp[0]; data.add_dependencies (yyvsp[0], deps); 
     deps.clear (); deps.push_back (yyvsp[0]); }
     break;
 
   case 10:
-#line 44 "../../drawtiming/src/parser.yy"
+#line 44 "parser.yy"
     { yyval = yyvsp[0]; data.add_delay (yyvsp[0], yyvsp[-2], yyvsp[-1]); }
     break;
 
   case 11:
-#line 47 "../../drawtiming/src/parser.yy"
+#line 47 "parser.yy"
     { yyval = yyvsp[-2]; data.set_value (yyvsp[-2], n, timing::sigvalue (yyvsp[0])); }
     break;
 
   case 12:
-#line 48 "../../drawtiming/src/parser.yy"
+#line 48 "parser.yy"
     { yyval = yyvsp[-2]; data.set_value (yyvsp[-2], n, timing::sigvalue (yyvsp[0], timing::STATE)); }
     break;
 
   case 13:
-#line 49 "../../drawtiming/src/parser.yy"
+#line 49 "parser.yy"
     { yyval = yyvsp[0]; }
     break;
 
@@ -1155,12 +1155,11 @@ yyerrlab:
 yyerrlab1:
 
   /* Suppress GCC warning that yyerrlab1 is unused when no action
-     invokes YYERROR.  Doesn't work in C++ */
-#ifndef __cplusplus
-#if defined (__GNUC_MINOR__) && 2093 <= (__GNUC__ * 1000 + __GNUC_MINOR__)
+     invokes YYERROR.  */
+#if defined (__GNUC_MINOR__) && 2093 <= (__GNUC__ * 1000 + __GNUC_MINOR__) \
+    && !defined __cplusplus
   __attribute__ ((__unused__))
 #endif
-#endif
 
 
   goto yyerrlab2;
@@ -1243,7 +1242,7 @@ yyreturn:
 }
 
 
-#line 51 "../../drawtiming/src/parser.yy"
+#line 51 "parser.yy"
 
 
 void yyerror (const char *s) {
